==> jc-1.4.0.tar.gz: gnu/xml/transform/WhenNode.h <==
// final class gnu.xml.transform.WhenNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 7e0aaa4e13b22f44 gnu_xml_transform_WhenNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_WhenNode_H_
#define _JC_gnu_xml_transform_WhenNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_WhenNode$sub_refs	_jc_gnu_xml_transform_WhenNode$sub_refs;
typedef struct _jc_gnu_xml_transform_WhenNode$sub_nonrefs	_jc_gnu_xml_transform_WhenNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_WhenNode$refs	_jc_gnu_xml_transform_WhenNode$refs;
typedef struct _jc_gnu_xml_transform_WhenNode$nonrefs	_jc_gnu_xml_transform_WhenNode$nonrefs;
typedef struct _jc_gnu_xml_transform_WhenNode$object	_jc_gnu_xml_transform_WhenNode$object;

typedef const struct _jc_gnu_xml_transform_WhenNode$vmethods	_jc_gnu_xml_transform_WhenNode$vmethods;
typedef const struct _jc_gnu_xml_transform_WhenNode$vtable	_jc_gnu_xml_transform_WhenNode$vtable;
typedef const struct _jc_gnu_xml_transform_WhenNode$vtype	_jc_gnu_xml_transform_WhenNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_WhenNode$method$_init$82d6ccf3b9e72058(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_WhenNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern void _jc_gnu_xml_transform_WhenNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_WhenNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_WhenNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *);
};

// Vtable
struct _jc_gnu_xml_transform_WhenNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_WhenNode$vmethods	gnu_xml_transform_WhenNode;
};

// Vtype
struct _jc_gnu_xml_transform_WhenNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_WhenNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_WhenNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*test;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_WhenNode$refs {
    _jc_gnu_xml_transform_WhenNode$sub_refs	gnu_xml_transform_WhenNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_WhenNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_WhenNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_WhenNode$sub_nonrefs	gnu_xml_transform_WhenNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_WhenNode$object {
	_jc_gnu_xml_transform_WhenNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_WhenNode$vtype	*vtype;
	_jc_gnu_xml_transform_WhenNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_WhenNode$vtype _jc_gnu_xml_transform_WhenNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_WhenNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_WhenNode$class_object;

#endif	/* _JC_gnu_xml_transform_WhenNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/WhenNode.h <==
// final class gnu.xml.transform.WhenNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 7e0aaa4e13b22f44 gnu_xml_transform_WhenNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_WhenNode_H_
#define _JC_gnu_xml_transform_WhenNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_WhenNode$sub_refs	_jc_gnu_xml_transform_WhenNode$sub_refs;
typedef struct _jc_gnu_xml_transform_WhenNode$sub_nonrefs	_jc_gnu_xml_transform_WhenNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_WhenNode$refs	_jc_gnu_xml_transform_WhenNode$refs;
typedef struct _jc_gnu_xml_transform_WhenNode$nonrefs	_jc_gnu_xml_transform_WhenNode$nonrefs;
typedef struct _jc_gnu_xml_transform_WhenNode$object	_jc_gnu_xml_transform_WhenNode$object;

typedef const struct _jc_gnu_xml_transform_WhenNode$vmethods	_jc_gnu_xml_transform_WhenNode$vmethods;
typedef const struct _jc_gnu_xml_transform_WhenNode$vtable	_jc_gnu_xml_transform_WhenNode$vtable;
typedef const struct _jc_gnu_xml_transform_WhenNode$vtype	_jc_gnu_xml_transform_WhenNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_WhenNode$method$_init$82d6ccf3b9e72058(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_WhenNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_WhenNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_WhenNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_WhenNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_WhenNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_WhenNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_WhenNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_WhenNode$vmethods	gnu_xml_transform_WhenNode;
};

// Vtype
struct _jc_gnu_xml_transform_WhenNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_WhenNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_WhenNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*test;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_WhenNode$refs {
    _jc_gnu_xml_transform_WhenNode$sub_refs	gnu_xml_transform_WhenNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_WhenNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_WhenNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_WhenNode$sub_nonrefs	gnu_xml_transform_WhenNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_WhenNode$object {
	_jc_gnu_xml_transform_WhenNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_WhenNode$vtype	*vtype;
	_jc_gnu_xml_transform_WhenNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_WhenNode$vtype _jc_gnu_xml_transform_WhenNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_WhenNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_WhenNode$class_object;

#endif	/* _JC_gnu_xml_transform_WhenNode_H_ */
